### 시작하기

PDFMathTranslate는 강력한 PDF 번역 도구입니다. 다양한 방법으로 이 도구를 설치하고 사용을 시작할 수 있습니다.

---

### 설치

1. [**Windows EXE**](./INSTALLATION_winexe.md) <small>Windows에 권장</small>
2. [**Docker**](./INSTALLATION_docker.md) <small>Linux에 권장</small>
3. [**uv** (a Python package manager)](./INSTALLATION_uv.md) <small>macOS에 권장</small>

---

### 사용법

1. [**WebUI** 사용하기](./USAGE_webui.md)
2. [**Zotero 플러그인** 사용하기](https://github.com/guaguastandup/zotero-pdf2zh) (서드파티 프로그램)
3. [**명령줄** 사용하기](./USAGE_commandline.md)

<div align="right"> 
<h6><small>이 페이지의 일부 내용은 GPT에 의해 번역되었으며 오류가 포함될 수 있습니다.</small></h6>